@@ -1,5 +1,6 @@
 import torch
 import torch.nn.functional as F
+from torchvision import transforms
 import numpy as np
 import matplotlib.pyplot as plt
 from torchsummary import summary
@@ -12,18 +13,12 @@ def model_summary(model):
     """Displays the Summary of the Architecture - All the methods used and the parameters used"""
     summary(model, input_size=(3, 32, 32))
 
-#To Display random pictures
-def unnorm(img, mean= (0.4914, 0.4822, 0.4465), std= (0.2023, 0.1994, 0.2010)):
-        for t, m, s in zip(img, mean, std):
-            t.mul_(s).add_(m)
-            # The normalize code -> t.sub_(m).div_(s)
-        return img
-
 def _imshow(img):
-    img = unnorm(img)      # unnormalize
+    inv_norm = transforms.Normalize(
+        mean=(-0.4914/0.2023, -0.4822/0.1994, -0.4465/0.2010),
+        std=(1/0.2023, 1/0.1994, 1/0.2010))
+    img = inv_norm(img)      # unnormalize
     npimg = img.numpy()
-    #print(npimg.shape)
-    #print(np.transpose(npimg, (1, 2, 0)).shape)
     plt.figure()
     plt.imshow(np.transpose(npimg, (1, 2, 0)))
 
@@ -33,7 +28,6 @@ def display(train_loader, n= 64,):
     dataiter = iter(train_loader)
     images, labels = dataiter.next()
     for i in range(0,n,int(np.sqrt(n))):
-        #print('the incoming image is ',images[i: i+int(np.sqrt(n))].shape)
         _imshow(torchvision.utils.make_grid(images[i: i+int(np.sqrt(n))]))
         # print labels
         plt.title(' '.join('%7s' % classes[j] for j in labels[i: i+int(np.sqrt(n))]), loc= 'left')
\ No newline at end of file
